@@ -1,6 +1,6 @@
 /*
  * plugins.h
- * Copyright 2010 John Lindgren
+ * Copyright 2010-2013 John Lindgren
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -24,6 +24,7 @@
 #include <audacious/types.h>
 #include <libaudcore/core.h>
 
+/* returns TRUE to call again for the next plugin, FALSE to stop */
 typedef bool_t (* PluginForEachFunc) (PluginHandle * plugin, void * data);
 
 #define AUD_API_NAME PluginsAPI
@@ -41,11 +42,6 @@ enum {
  INPUT_KEY_MIME,
  INPUT_KEYS};
 
-typedef struct {
-    void * about_window;
-    void * config_window;
-} PluginMiscData;
-
 /* plugin-init.c */
 void start_plugins_one (void);
 void start_plugins_two (void);
@@ -57,17 +53,14 @@ void plugin_registry_load (void);
 void plugin_registry_prune (void);
 void plugin_registry_save (void);
 
-void plugin_register (const char * path);
-void plugin_register_loaded (const char * path, Plugin * header);
+void plugin_register (const char * path, int timestamp);
 
-const void * plugin_get_header_no_load (PluginHandle * plugin);
 void plugin_set_enabled (PluginHandle * plugin, bool_t enabled);
-PluginMiscData * plugin_get_misc_data (PluginHandle * plugin);
+void * plugin_get_misc_data (PluginHandle * plugin, int size);
 
 PluginHandle * transport_plugin_for_scheme (const char * scheme);
-PluginHandle * playlist_plugin_for_extension (const char * extension);
-void input_plugin_for_key (int key, const char * value, PluginForEachFunc
- func, void * data);
+void playlist_plugin_for_ext (const char * ext, PluginForEachFunc func, void * data);
+void input_plugin_for_key (int key, const char * value, PluginForEachFunc func, void * data);
 bool_t input_plugin_has_images (PluginHandle * plugin);
 bool_t input_plugin_has_subtunes (PluginHandle * plugin);
 bool_t input_plugin_can_write_tuple (PluginHandle * plugin);
@@ -76,7 +69,7 @@ bool_t input_plugin_has_infowin (PluginHandle * plugin);
 /* pluginenum.c */
 void plugin_system_init (void);
 void plugin_system_cleanup (void);
-void plugin_load (const char * path);
+Plugin * plugin_load (const char * path);
 
 #else
 
